==> static_postgres_orm-0.0.1-dev.1.tar.gz: lib/src/postgres/orm_postgres_types.dart <==
import 'package:dartz/dartz.dart';
import 'package:postgres/postgres.dart';
import 'package:data_db/data_db.dart';
import '../domain/orm_data_types.dart';
import '../domain/orm_domain_types.dart';

ExecuteSuccesSqlResult pgQueryToExecuteSuccesSqlResult(String className,
    String methodName, String sqlCommand, PostgreSQLResult pgQuery) {
  return ExecuteSuccesSqlResult(
      className, methodName, pgQuery.affectedRowCount);
}

SelectSuccesSqlResult pgQueryToSelectSuccesSqlResult(String className,
    String methodName, String sqlCommand, PostgreSQLResult pgQuery) {
  return SelectSuccesSqlResult(
      className, methodName, pgQuery.affectedRowCount, pgQuery)
    ..dataset = pgSqlToDataset(pgQuery);
}

ErrorSqlResult pgExceptionToErrorSqlResult(String className, String methodName,
    String sqlCommand, PostgreSQLException e) {
  return ErrorSqlResult(className, methodName, sqlCommand, [e.message ?? ''],
      errorCode: e.code);
}

class Postgres_SqlConnection extends SqlConnection {
  late String className;
  String host = '';
  int port = 5432;
  String databaseName = 'postgres';
  String username = 'postgres';
  String password = '';
  int timeoutInSeconds = 30;
  int queryTimeoutInSeconds = 30;
  String timeZone = 'UTC';
  bool useSSL = false;
  bool isUnixSocket = false;

  Postgres_SqlConnection(
    this.host,
    this.port,
    this.databaseName,
    this.username,
    this.password, {
    timeoutInSeconds,
    queryTimeoutInSeconds,
    timeZone,
    useSSL,
    isUnixSocket,
  }) {
    if (useSSL != null) this.useSSL = useSSL;
  }

  PostgreSQLConnection newConnection() {
    return PostgreSQLConnection(host, port, databaseName,
        username: username,
        password: password,
        timeoutInSeconds: timeoutInSeconds,
        queryTimeoutInSeconds: queryTimeoutInSeconds,
        timeZone: timeZone,
        useSSL: useSSL,
        isUnixSocket: isUnixSocket);
  }

  @override
  Future<Either<ErrorSqlResult, ExecuteSuccesSqlResult>> executeCommand(
      String methodName, String sql) async {
    var _dbConnection = newConnection();
    try {
      await _dbConnection.open();
      return right(pgQueryToExecuteSuccesSqlResult(
          className, methodName, sql, (await _dbConnection.query(sql))));
    } on PostgreSQLException catch (e) {
      return left(pgExceptionToErrorSqlResult(className, methodName, sql, e));
    } catch (e) {
      return left(ErrorSqlResult(className, methodName, sql, [e.toString()]));
    } finally {
      await _dbConnection.close();
    }
  }

  @override
  Future<Either<ErrorSqlResult, SelectSuccesSqlResult>> openQuery(
      String methodName, String sql) async {
    var _dbConnection = newConnection();
    try {
      await _dbConnection.open();
      return right(pgQueryToSelectSuccesSqlResult(
          className, methodName, sql, (await _dbConnection.query(sql))));
    } on PostgreSQLException catch (e) {
      return left(pgExceptionToErrorSqlResult(className, methodName, sql, e));
    } catch (e) {
      return left(ErrorSqlResult(className, methodName, sql, [e.toString()]));
    } finally {
      await _dbConnection.close();
    }
  }
}

abstract class PostgressORM extends ORM {
  late final String _className =
      toString().replaceFirst('Instance of ', '').replaceAll("'", '');
  final Postgres_SqlConnection _postgresConnection;

  PostgressORM(this._postgresConnection, schemaName, tableName, Event addRecord)
      : super(_postgresConnection, schemaName, tableName, addRecord) {
    _postgresConnection.className = _className;
  }
}

DataField getFieldClass(Dataset ds, FieldDescription field) {
  if (field.typeID == 16) {
    return BooleanDataField();
  } else if ((field.typeID == 16) ||
      (field.typeID == 19) ||
      (field.typeID == 1043) ||
      (field.typeID == 25)) {
    return StringDataField();
  } else if (field.typeID == 16) {
    return StringDataField();
  } else if ((field.typeID == 20) ||
      (field.typeID == 21) ||
      (field.typeID == 23)) {
    return IntegerDataField();
  } else if ((field.typeID == 700) ||
      (field.typeID == 701) ||
      (field.typeID == 790) ||
      (field.typeID == 1700)) {
    return NumericDataField();
  } else if (field.typeID == 1082) {
    return DateDataField();
  } else if ((field.typeID == 1083) || (field.typeID == 1266)) {
    return TimeDataField();
  } else if ((field.typeID == 1114) || (field.typeID == 1184)) {
    return DateTimeDataField();
  } else {
    return DynamicDataField();
  }
}

Type getFieldType(FieldDescription field) {
  if (field.typeID == 16) {
    return BooleanDataField;
  } else if ((field.typeID == 16) ||
      (field.typeID == 19) ||
      (field.typeID == 1043) ||
      (field.typeID == 25)) {
    return StringDataField;
  } else if (field.typeID == 16) {
    return StringDataField;
  } else if ((field.typeID == 20) ||
      (field.typeID == 21) ||
      (field.typeID == 23)) {
    return IntegerDataField;
  } else if ((field.typeID == 700) ||
      (field.typeID == 701) ||
      (field.typeID == 790) ||
      (field.typeID == 1700)) {
    return NumericDataField;
  } else if (field.typeID == 1082) {
    return DateDataField;
  } else if ((field.typeID == 1083) || (field.typeID == 1266)) {
    return TimeDataField;
  } else if ((field.typeID == 1114) || (field.typeID == 1184)) {
    return DateTimeDataField;
  } else {
    return DynamicDataField;
  }
}

Dataset pgSqlToDataset(PostgreSQLResult pg) {
  var ds = Dataset();
  var fieldDescription = pg.columnDescriptions as List<FieldDescription>;
  fieldDescription.forEach((element) {
    ds.structure.addAll({element.columnName: getFieldType(element)});
  });

  var i = -1;

  for (final row in pg) {
    ds.newRecord();
    i = -1;
    fieldDescription.forEach((element) {
      i++;
      ds.trySetValue(element.columnName, row[i]);
    });
  }

  return ds;
}

==> static_postgres_orm-0.0.2-dev.tar.gz: lib/src/postgres/orm_postgres_types.dart <==
import 'package:dartz/dartz.dart';
import 'package:static_postgres_orm/dependencies/postgresql/lib/postgres.dart';
import 'package:data_db/data_db.dart';
import 'package:static_postgres_orm/dependencies/postgresql/lib/src/query.dart';
import '../domain/orm_data_types.dart';
import '../domain/orm_domain_types.dart';

ExecuteSuccesSqlResult pgQueryToExecuteSuccesSqlResult(String className,
    String methodName, String sqlCommand, PostgreSQLResult pgQuery) {
  return ExecuteSuccesSqlResult(
      className, methodName, pgQuery.affectedRowCount);
}

SelectSuccesSqlResult pgQueryToSelectSuccesSqlResult(String className,
    String methodName, String sqlCommand, PostgreSQLResult pgQuery) {
  return SelectSuccesSqlResult(
      className, methodName, pgQuery.affectedRowCount, pgQuery)
    ..dataset = pgSqlToDataset(pgQuery);
}

ErrorSqlResult pgExceptionToErrorSqlResult(String className, String methodName,
    String sqlCommand, PostgreSQLException e) {
  return ErrorSqlResult(className, methodName, sqlCommand, [e.message ?? ''],
      errorCode: e.code);
}

class Postgres_SqlConnection extends SqlConnection {
  late String className;
  String host = '';
  int port = 5432;
  String databaseName = 'postgres';
  String username = 'postgres';
  String password = '';
  int timeoutInSeconds = 30;
  int queryTimeoutInSeconds = 30;
  String timeZone = 'UTC';
  bool useSSL = false;
  bool isUnixSocket = false;

  Postgres_SqlConnection(
    this.host,
    this.port,
    this.databaseName,
    this.username,
    this.password, {
    timeoutInSeconds,
    queryTimeoutInSeconds,
    timeZone,
    useSSL,
    isUnixSocket,
  }) {
    if (useSSL != null) this.useSSL = useSSL;
  }

  PostgreSQLConnection newConnection() {
    return PostgreSQLConnection(host, port, databaseName,
        username: username,
        password: password,
        timeoutInSeconds: timeoutInSeconds,
        queryTimeoutInSeconds: queryTimeoutInSeconds,
        timeZone: timeZone,
        useSSL: useSSL,
        isUnixSocket: isUnixSocket);
  }

  @override
  Future<Either<ErrorSqlResult, ExecuteSuccesSqlResult>> executeCommand(
      String methodName, String sql) async {
    var _dbConnection = newConnection();
    try {
      await _dbConnection.open();
      return right(pgQueryToExecuteSuccesSqlResult(
          className, methodName, sql, (await _dbConnection.query(sql))));
    } on PostgreSQLException catch (e) {
      return left(pgExceptionToErrorSqlResult(className, methodName, sql, e));
    } catch (e) {
      return left(ErrorSqlResult(className, methodName, sql, [e.toString()]));
    } finally {
      await _dbConnection.close();
    }
  }

  @override
  Future<Either<ErrorSqlResult, SelectSuccesSqlResult>> openQuery(
      String methodName, String sql) async {
    var _dbConnection = newConnection();
    try {
      await _dbConnection.open();
      return right(pgQueryToSelectSuccesSqlResult(
          className, methodName, sql, (await _dbConnection.query(sql))));
    } on PostgreSQLException catch (e) {
      return left(pgExceptionToErrorSqlResult(className, methodName, sql, e));
    } catch (e) {
      return left(ErrorSqlResult(className, methodName, sql, [e.toString()]));
    } finally {
      await _dbConnection.close();
    }
  }
}

abstract class PostgressORM extends ORM {
  late final String _className =
      toString().replaceFirst('Instance of ', '').replaceAll("'", '');
  final Postgres_SqlConnection _postgresConnection;

  PostgressORM(this._postgresConnection, schemaName, tableName, Event addRecord)
      : super(_postgresConnection, schemaName, tableName, addRecord) {
    _postgresConnection.className = _className;
  }
}

DataField getFieldClass(Dataset ds, FieldDescription field) {
  if (field.typeID == 16) {
    return BooleanDataField();
  } else if ((field.typeID == 16) ||
      (field.typeID == 19) ||
      (field.typeID == 1043) ||
      (field.typeID == 25)) {
    return StringDataField();
  } else if (field.typeID == 16) {
    return StringDataField();
  } else if ((field.typeID == 20) ||
      (field.typeID == 21) ||
      (field.typeID == 23)) {
    return IntegerDataField();
  } else if ((field.typeID == 700) ||
      (field.typeID == 701) ||
      (field.typeID == 790) ||
      (field.typeID == 1700)) {
    return NumericDataField();
  } else if (field.typeID == 1082) {
    return DateDataField();
  } else if ((field.typeID == 1083) || (field.typeID == 1266)) {
    return TimeDataField();
  } else if ((field.typeID == 1114) || (field.typeID == 1184)) {
    return DateTimeDataField();
  } else {
    return DynamicDataField();
  }
}

Type getFieldType(FieldDescription field) {
  if (field.typeID == 16) {
    return BooleanDataField;
  } else if ((field.typeID == 16) ||
      (field.typeID == 19) ||
      (field.typeID == 1043) ||
      (field.typeID == 25)) {
    return StringDataField;
  } else if (field.typeID == 16) {
    return StringDataField;
  } else if ((field.typeID == 20) ||
      (field.typeID == 21) ||
      (field.typeID == 23)) {
    return IntegerDataField;
  } else if ((field.typeID == 700) ||
      (field.typeID == 701) ||
      (field.typeID == 790) ||
      (field.typeID == 1700)) {
    return NumericDataField;
  } else if (field.typeID == 1082) {
    return DateDataField;
  } else if ((field.typeID == 1083) || (field.typeID == 1266)) {
    return TimeDataField;
  } else if ((field.typeID == 1114) || (field.typeID == 1184)) {
    return DateTimeDataField;
  } else {
    return DynamicDataField;
  }
}

Dataset pgSqlToDataset(PostgreSQLResult pg) {
  var ds = Dataset();
  var fieldDescription = pg.columnDescriptions;
  fieldDescription.forEach((element) {
    ds.structure.addAll(
        {element.columnName: getFieldType(element as FieldDescription)});
  });

  var i = -1;

  for (final row in pg) {
    ds.newRecord();
    i = -1;
    fieldDescription.forEach((element) {
      i++;
      ds.trySetValue(element.columnName, row[i]);
    });
  }

  return ds;
}
